@@ -22,7 +22,6 @@
 #include <stdio.h>
 #include <X11/Xatom.h>
 #include <X11/extensions/shape.h>
-#include <X11/extensions/Xinerama.h>
 
 #include "client.h"
 #include "tag.h"
@@ -30,10 +29,12 @@
 #include "window.h"
 #include "focus.h"
 #include "ewmh.h"
-#include "screen.h"
 #include "widget.h"
-#include "xutil.h"
+#include "screen.h"
+#include "titlebar.h"
 #include "layouts/floating.h"
+#include "common/xutil.h"
+#include "common/xscreen.h"
 
 extern AwesomeConf globalconf;
 
@@ -57,7 +58,7 @@ client_loadprops(Client * c, int screen)
 
     prop = p_new(char, ntags + 2);
 
-    if(xgettextprop(c->win,
+    if(xgettextprop(globalconf.display, c->win,
                     XInternAtom(globalconf.display, "_AWESOME_PROPERTIES", False),
                     prop, ntags + 2))
     {
@@ -138,8 +139,12 @@ client_get_byname(Client *list, char *name)
 void
 client_updatetitle(Client *c)
 {
-    if(!xgettextprop(c->win, XInternAtom(globalconf.display, "_NET_WM_NAME", False), c->name, sizeof(c->name)))
-        xgettextprop(c->win, XInternAtom(globalconf.display, "WM_NAME", False), c->name, sizeof(c->name));
+    if(!xgettextprop(globalconf.display, c->win,
+                     XInternAtom(globalconf.display, "_NET_WM_NAME", False), c->name, sizeof(c->name)))
+        xgettextprop(globalconf.display, c->win,
+                     XInternAtom(globalconf.display, "WM_NAME", False), c->name, sizeof(c->name));
+
+    titlebar_draw(c);
 
     widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
 }
@@ -149,10 +154,13 @@ client_unfocus(Client *c)
 {
     if(globalconf.screens[c->screen].opacity_unfocused != -1)
         window_settrans(c->win, globalconf.screens[c->screen].opacity_unfocused);
-    XSetWindowBorder(globalconf.display, c->win,
-                     globalconf.screens[c->screen].colors_normal[ColBorder].pixel);
-    widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
+    else if(globalconf.screens[c->screen].opacity_focused != -1)
+        window_settrans(c->win, -1);
     focus_add_client(NULL);
+    XSetWindowBorder(globalconf.display, c->win,
+                     globalconf.screens[c->screen].styles.normal.border.pixel);
+    widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
+    titlebar_draw(c);
 }
 
 /** Ban client and unmap it
@@ -165,25 +173,30 @@ client_ban(Client *c)
         client_unfocus(c);
     XUnmapWindow(globalconf.display, c->win);
     window_setstate(c->win, IconicState);
+    if(c->titlebar.position && c->titlebar.sw)
+        XUnmapWindow(globalconf.display, c->titlebar.sw->window);
 }
 
 /** Give focus to client, or to first client if c is NULL
  * \param c client
  * \param screen Screen ID
+ * \param raise raise window if true
+ * \return true if a window (even root) has received focus, false otherwise
  */
-void
+Bool
 client_focus(Client *c, int screen, Bool raise)
 {
-    int phys_screen = get_phys_screen(screen);
+    int phys_screen;
 
     /* if c is NULL or invisible, take next client in the focus history */
-    if(!c || (c && !client_isvisible(c, screen)))
-    {
-        c = focus_get_current_client(screen);
+    if((!c || (c && (!client_isvisible(c, screen))))
+       && !(c = focus_get_current_client(screen)))
         /* if c is still NULL take next client in the stack */
-        if(!c)
-            for(c = globalconf.clients; c && (c->skip || !client_isvisible(c, screen)); c = c->next);
-    }
+        for(c = globalconf.clients; c && (c->skip || !client_isvisible(c, screen)); c = c->next);
+
+    /* if c is already the focused window, then stop */
+    if(c == globalconf.focus->client)
+        return False;
 
     /* unfocus current selected client */
     if(globalconf.focus->client)
@@ -195,49 +208,85 @@ client_focus(Client *c, int screen, Bool raise)
         client_unban(c);
         /* save sel in focus history */
         focus_add_client(c);
-        if(globalconf.screens[c->screen].opacity_unfocused != -1)
+        if(globalconf.screens[c->screen].opacity_focused != -1)
+            window_settrans(c->win, globalconf.screens[c->screen].opacity_focused);
+        else if(globalconf.screens[c->screen].opacity_unfocused != -1)
             window_settrans(c->win, -1);
         XSetWindowBorder(globalconf.display, c->win,
-                         globalconf.screens[screen].colors_selected[ColBorder].pixel);
+                         globalconf.screens[screen].styles.focus.border.pixel);
+        titlebar_draw(c);
         XSetInputFocus(globalconf.display, c->win, RevertToPointerRoot, CurrentTime);
         if(raise)
-        {
-            XWindowChanges wc;
-            Layout *curlay = layout_get_current(screen);
-            if(c->isfloating || curlay->arrange == layout_floating)
-                XRaiseWindow(globalconf.display, c->win);
-            else
-            {
-                Client *client;
-                wc.stack_mode = Below;
-                wc.sibling = None;
-                for(client = globalconf.clients; client; client = client->next)
-                    if(client != c && client_isvisible(client, c->screen) && client->isfloating)
-                    {
-                        XConfigureWindow(globalconf.display, client->win, CWSibling | CWStackMode, &wc);
-                        wc.sibling = client->win;
-                    }
-                XConfigureWindow(globalconf.display, c->win, CWSibling | CWStackMode, &wc);
-                wc.sibling = c->win;
-                for(client = globalconf.clients; client; client = client->next)
-                    if(client != c && IS_TILED(client, c->screen))
-                    {
-                        XConfigureWindow(globalconf.display, client->win, CWSibling | CWStackMode, &wc);
-                        wc.sibling = client->win;
-                    }
-            }
-        }
+            client_stack(c);
         /* since we're dropping EnterWindow events and sometimes the window
          * will appear under the mouse, grabbuttons */
-        window_grabbuttons(phys_screen, c->win);
+        window_grabbuttons(c->win, c->phys_screen);
+        phys_screen = c->phys_screen;
     }
     else
+    {
+        phys_screen = screen_virttophys(screen);
         XSetInputFocus(globalconf.display,
                        RootWindow(globalconf.display, phys_screen),
                        RevertToPointerRoot, CurrentTime);
+    }
 
-    widget_invalidate_cache(screen, WIDGET_CACHE_CLIENTS);
     ewmh_update_net_active_window(phys_screen);
+    widget_invalidate_cache(screen, WIDGET_CACHE_CLIENTS);
+
+    return True;
+}
+
+void
+client_stack(Client *c)
+{
+    XWindowChanges wc;
+    Layout *curlay = layout_get_current(c->screen);
+
+    if(c->isfloating || curlay->arrange == layout_floating)
+    {
+        XRaiseWindow(globalconf.display, c->win);
+        if(c->titlebar.position && c->titlebar.sw)
+            XRaiseWindow(globalconf.display, c->titlebar.sw->window);
+    }
+    else
+    {
+        Client *client;
+        wc.stack_mode = Below;
+        wc.sibling = None;
+        for(client = globalconf.clients; client; client = client->next)
+            if(client != c && client_isvisible(client, c->screen) && client->isfloating)
+            {
+                if(client->titlebar.position && client->titlebar.sw)
+                {
+                    XConfigureWindow(globalconf.display, client->titlebar.sw->window,
+                                     CWSibling | CWStackMode, &wc);
+                    wc.sibling = client->titlebar.sw->window;
+                }
+                XConfigureWindow(globalconf.display, client->win, CWSibling | CWStackMode, &wc);
+                wc.sibling = client->win;
+            }
+        if(c->titlebar.position && c->titlebar.sw)
+        {
+             XConfigureWindow(globalconf.display, c->titlebar.sw->window,
+                              CWSibling | CWStackMode, &wc);
+             wc.sibling = c->titlebar.sw->window;
+        }
+        XConfigureWindow(globalconf.display, c->win, CWSibling | CWStackMode, &wc);
+        wc.sibling = c->win;
+        for(client = globalconf.clients; client; client = client->next)
+            if(client != c && IS_TILED(client, c->screen))
+            {
+                if(client->titlebar.position && client->titlebar.sw)
+                {
+                    XConfigureWindow(globalconf.display, client->titlebar.sw->window,
+                                     CWSibling | CWStackMode, &wc);
+                    wc.sibling = client->titlebar.sw->window;
+                }
+                XConfigureWindow(globalconf.display, client->win, CWSibling | CWStackMode, &wc);
+                wc.sibling = client->win;
+            }
+    }
 }
 
 /** Manage a new client
@@ -254,32 +303,30 @@ client_manage(Window w, XWindowAttributes *wa, int screen)
     XWindowChanges wc;
     Tag *tag;
     Rule *rule;
-    Area screen_geom;
-    int phys_screen = get_phys_screen(screen);
     long flags;
 
     c = p_new(Client, 1);
 
-    c->screen = screen_get_bycoord(screen, wa->x, wa->y);
+    c->screen = screen_get_bycoord(globalconf.screens_info, screen, wa->x, wa->y);
+
+    if(globalconf.screens_info->xinerama_is_active)
+        c->phys_screen = DefaultScreen(globalconf.display);
+    else
+        c->phys_screen = c->screen;
 
-    screen_geom = screen_get_area(c->screen,
-                                  globalconf.screens[screen].statusbar,
-                                  &globalconf.screens[screen].padding);
     /* Initial values */
     c->win = w;
-    c->geometry.x = c->f_geometry.x = c->m_geometry.x = MAX(wa->x, screen_geom.x);
-    c->geometry.y = c->f_geometry.y = c->m_geometry.y = MAX(wa->y, screen_geom.y);
+    c->geometry.x = c->f_geometry.x = c->m_geometry.x = wa->x;
+    c->geometry.y = c->f_geometry.y = c->m_geometry.y = wa->y;
     c->geometry.width = c->f_geometry.width = c->m_geometry.width = wa->width;
     c->geometry.height = c->f_geometry.height = c->m_geometry.height = wa->height;
     c->oldborder = wa->border_width;
     c->newcomer = True;
 
-    c->border = globalconf.screens[screen].borderpx;
-
     /* Set windows borders */
-    wc.border_width = c->border;
+    wc.border_width = c->border = globalconf.screens[screen].borderpx;
     XConfigureWindow(globalconf.display, w, CWBorderWidth, &wc);
-    XSetWindowBorder(globalconf.display, w, globalconf.screens[screen].colors_normal[ColBorder].pixel);
+    XSetWindowBorder(globalconf.display, w, c->border);
     /* propagates border_width, if size doesn't change */
     window_configure(c->win, c->geometry, c->border);
 
@@ -291,40 +338,39 @@ client_manage(Window w, XWindowAttributes *wa, int screen)
     client_updatewmhints(c);
 
     /* Try to load props if any */
-    retloadprops = client_loadprops(c, screen);
+    if(!(retloadprops = client_loadprops(c, screen)))
+        move_client_to_screen(c, screen, True);
 
     /* Then check clients hints */
     ewmh_check_client_hints(c);
 
+    /* default titlebar position */
+    c->titlebar = globalconf.screens[screen].titlebar_default;
+
+    /* get the matching rule if any */
+    rule = rule_matching_client(c);
+
     /* Then apply rules if no props */
-    if(!retloadprops)
+    if(!retloadprops && rule)
     {
-        /* Get the client's rule */
-        if((rule = rule_matching_client(c)))
+        if(rule->screen != RULE_NOSCREEN)
+            move_client_to_screen(c, rule->screen, True);
+        tag_client_with_rule(c, rule);
+
+        switch(rule->isfloating)
         {
-            if(rule->screen != RULE_NOSCREEN)
-                move_client_to_screen(c, rule->screen, True);
-            else
-                move_client_to_screen(c, screen, True);
-            tag_client_with_rule(c, rule);
-
-            switch(rule->isfloating)
-            {
-              case Auto:
-                break;
-              case Yes:
-                client_setfloating(c, True);
-                break;
-              case No:
-                client_setfloating(c, False);
-                break;
-            }
-
-            if(rule->opacity >= 0.0f)
-                window_settrans(c->win, rule->opacity);
+          case Maybe:
+            break;
+          case Yes:
+            client_setfloating(c, True);
+            break;
+          case No:
+            client_setfloating(c, False);
+            break;
         }
-        else
-            move_client_to_screen(c, screen, True);
+
+        if(rule->opacity >= 0.0f)
+            window_settrans(c->win, rule->opacity);
     }
 
     /* check for transient and set tags like its parent,
@@ -337,12 +383,25 @@ client_manage(Window w, XWindowAttributes *wa, int screen)
                 tag_client(c, tag);
 
     /* should be floating if transsient or fixed */
-    if(!c->isfloating)
-        client_setfloating(c, rettrans || c->isfixed);
+    if(rettrans || c->isfixed)
+        client_setfloating(c, True);
 
-    if(!(flags & (USPosition | PPosition)))
-        c->f_geometry =
-            globalconf.screens[c->screen].floating_placement(c->f_geometry, c->border, c->screen);
+    /* titlebar init */
+    if(rule && rule->titlebar.position != Auto)
+        c->titlebar = rule->titlebar;
+
+    titlebar_init(c);
+
+    if(!retloadprops && !(flags & (USPosition | PPosition)))
+    {
+        if(c->isfloating && !c->ismax)
+            client_resize(c, globalconf.screens[c->screen].floating_placement(c), False);
+        else
+            c->f_geometry = globalconf.screens[c->screen].floating_placement(c);
+    }
+
+    /* update titlebar with real floating info now */
+    titlebar_update_geometry_floating(c);
 
     XSelectInput(globalconf.display, w, StructureNotifyMask | PropertyChangeMask | EnterWindowMask);
 
@@ -350,11 +409,11 @@ client_manage(Window w, XWindowAttributes *wa, int screen)
     if(globalconf.have_shape)
     {
         XShapeSelectInput(globalconf.display, w, ShapeNotifyMask);
-        window_setshape(phys_screen, c->win);
+        window_setshape(c->win, c->phys_screen);
     }
 
     /* attach to the stack */
-    if((rule = rule_matching_client(c)))
+    if(rule)
         switch(rule->ismaster)
         {
           case Yes:
@@ -363,7 +422,7 @@ client_manage(Window w, XWindowAttributes *wa, int screen)
           case No:
             client_list_append(&globalconf.clients, c);
             break;
-          case Auto:
+          case Maybe:
             rule = NULL;
             break;
         }
@@ -376,75 +435,88 @@ client_manage(Window w, XWindowAttributes *wa, int screen)
             client_list_append(&globalconf.clients, c);
     }
 
-    /* some windows require this */
-    XMoveResizeWindow(globalconf.display, c->win, c->geometry.x, c->geometry.y,
-                      c->geometry.width, c->geometry.height);
-
     widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
-    ewmh_update_net_client_list(phys_screen);
+    ewmh_update_net_client_list(c->phys_screen);
+}
+
+static area_t
+client_geometry_hints(Client *c, area_t geometry)
+{
+    double dx, dy, max, min, ratio;
+
+    if(c->minay > 0 && c->maxay > 0 && (geometry.height - c->baseh) > 0
+       && (geometry.width - c->basew) > 0)
+    {
+        dx = (double) (geometry.width - c->basew);
+        dy = (double) (geometry.height - c->baseh);
+        min = (double) (c->minax) / (double) (c->minay);
+        max = (double) (c->maxax) / (double) (c->maxay);
+        ratio = dx / dy;
+        if(max > 0 && min > 0 && ratio > 0)
+        {
+            if(ratio < min)
+            {
+                dy = (dx * min + dy) / (min * min + 1);
+                dx = dy * min;
+                geometry.width = (int) dx + c->basew;
+                geometry.height = (int) dy + c->baseh;
+            }
+            else if(ratio > max)
+            {
+                dy = (dx * min + dy) / (max * max + 1);
+                dx = dy * min;
+                geometry.width = (int) dx + c->basew;
+                geometry.height = (int) dy + c->baseh;
+            }
+        }
+    }
+    if(c->minw && geometry.width < c->minw)
+        geometry.width = c->minw;
+    if(c->minh && geometry.height < c->minh)
+        geometry.height = c->minh;
+    if(c->maxw && geometry.width > c->maxw)
+        geometry.width = c->maxw;
+    if(c->maxh && geometry.height > c->maxh)
+        geometry.height = c->maxh;
+    if(c->incw)
+        geometry.width -= (geometry.width - c->basew) % c->incw;
+    if(c->inch)
+        geometry.height -= (geometry.height - c->baseh) % c->inch;
+
+    return geometry;
 }
 
 /** Resize client window
  * \param c client to resize
  * \param geometry new window geometry
- * \param sizehints respect size hints
+ * \param hints use resize hints
  * \param return True if resize has been done
  */
 Bool
-client_resize(Client *c, Area geometry, Bool sizehints)
+client_resize(Client *c, area_t geometry, Bool hints)
 {
     int new_screen;
-    double dx, dy, max, min, ratio;
-    Area area;
+    area_t area;
     XWindowChanges wc;
+    Layout *layout = layout_get_current(c->screen);
+    Bool resized = False;
 
-    if(sizehints)
+    if(!c->ismoving && !c->isfloating && layout->arrange != layout_floating)
     {
-        if(c->minay > 0 && c->maxay > 0 && (geometry.height - c->baseh) > 0
-           && (geometry.width - c->basew) > 0)
-        {
-            dx = (double) (geometry.width - c->basew);
-            dy = (double) (geometry.height - c->baseh);
-            min = (double) (c->minax) / (double) (c->minay);
-            max = (double) (c->maxax) / (double) (c->maxay);
-            ratio = dx / dy;
-            if(max > 0 && min > 0 && ratio > 0)
-            {
-                if(ratio < min)
-                {
-                    dy = (dx * min + dy) / (min * min + 1);
-                    dx = dy * min;
-                    geometry.width = (int) dx + c->basew;
-                    geometry.height = (int) dy + c->baseh;
-                }
-                else if(ratio > max)
-                {
-                    dy = (dx * min + dy) / (max * max + 1);
-                    dx = dy * min;
-                    geometry.width = (int) dx + c->basew;
-                    geometry.height = (int) dy + c->baseh;
-                }
-            }
-        }
-        if(c->minw && geometry.width < c->minw)
-            geometry.width = c->minw;
-        if(c->minh && geometry.height < c->minh)
-            geometry.height = c->minh;
-        if(c->maxw && geometry.width > c->maxw)
-            geometry.width = c->maxw;
-        if(c->maxh && geometry.height > c->maxh)
-            geometry.height = c->maxh;
-        if(c->incw)
-            geometry.width -= (geometry.width - c->basew) % c->incw;
-        if(c->inch)
-            geometry.height -= (geometry.height - c->baseh) % c->inch;
+        titlebar_update_geometry(c, geometry);
+        geometry = titlebar_geometry_remove(&c->titlebar, geometry);
     }
+
+    if(hints)
+        geometry = client_geometry_hints(c, geometry);
+
     if(geometry.width <= 0 || geometry.height <= 0)
         return False;
+
     /* offscreen appearance fixes */
-    area = get_display_area(get_phys_screen(c->screen),
-                            NULL,
+    area = get_display_area(c->phys_screen, NULL,
                             &globalconf.screens[c->screen].padding);
+
     if(geometry.x > area.width)
         geometry.x = area.width - geometry.width - 2 * c->border;
     if(geometry.y > area.height)
@@ -457,19 +529,24 @@ client_resize(Client *c, Area geometry, Bool sizehints)
     if(c->geometry.x != geometry.x || c->geometry.y != geometry.y
        || c->geometry.width != geometry.width || c->geometry.height != geometry.height)
     {
-        new_screen = screen_get_bycoord(c->screen, geometry.x, geometry.y);
+        new_screen =
+            screen_get_bycoord(globalconf.screens_info, c->screen, geometry.x, geometry.y);
 
         c->geometry.x = wc.x = geometry.x;
-        c->geometry.y = wc.y = geometry.y;
         c->geometry.width = wc.width = geometry.width;
+        c->geometry.y = wc.y = geometry.y;
         c->geometry.height = wc.height = geometry.height;
         wc.border_width = c->border;
 
         /* save the floating geometry if the window is floating but not
          * maximized */
-        if((c->isfloating ||
-           layout_get_current(new_screen)->arrange == layout_floating) && !c->ismax)
-            c->f_geometry = geometry;
+        if(c->ismoving || c->isfloating
+           || layout_get_current(new_screen)->arrange == layout_floating)
+        {
+            if(!c->ismax)
+                c->f_geometry = geometry;
+            titlebar_update_geometry_floating(c);
+        }
 
         XConfigureWindow(globalconf.display, c->win,
                          CWX | CWY | CWWidth | CWHeight | CWBorderWidth, &wc);
@@ -478,9 +555,15 @@ client_resize(Client *c, Area geometry, Bool sizehints)
         if(c->screen != new_screen)
             move_client_to_screen(c, new_screen, False);
 
-        return True;
+        resized = True;
     }
-    return False;
+
+    /* call it again like it was floating,
+     * we want it to be sticked to the window */
+    if(!c->ismoving && !c->isfloating && layout->arrange != layout_floating)
+       titlebar_update_geometry_floating(c);
+
+    return resized;
 }
 
 void
@@ -493,14 +576,10 @@ client_setfloating(Client *c, Bool floating)
             client_resize(c, c->f_geometry, False);
             XRaiseWindow(globalconf.display, c->win);
         }
-        else
+        else if(c->ismax)
         {
-            XLowerWindow(globalconf.display, c->win);
-            if(c->ismax)
-            {
-                c->ismax = False;
-                client_resize(c, c->m_geometry, False);
-            }
+            c->ismax = False;
+            client_resize(c, c->m_geometry, False);
         }
         if(client_isvisible(c, c->screen))
             globalconf.screens[c->screen].need_arrange = True;
@@ -544,6 +623,8 @@ client_unban(Client *c)
 {
     XMapWindow(globalconf.display, c->win);
     window_setstate(c->win, NormalState);
+    if(c->titlebar.sw && c->titlebar.position != Off)
+        XMapWindow(globalconf.display, c->titlebar.sw->window);
 }
 
 void
@@ -576,6 +657,9 @@ client_unmanage(Client *c)
     XSync(globalconf.display, False);
     XUngrabServer(globalconf.display);
 
+    if(c->titlebar.sw)
+        simplewindow_delete(&c->titlebar.sw);
+
     p_delete(&c);
 }
 
@@ -586,8 +670,11 @@ client_updatewmhints(Client *c)
 
     if((wmh = XGetWMHints(globalconf.display, c->win)))
     {
-        if((c->isurgent = (wmh->flags & XUrgencyHint)))
+        if((c->isurgent = ((wmh->flags & XUrgencyHint) && globalconf.focus->client != c)))
+        {
             widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
+            titlebar_draw(c);
+        }
         if((wmh->flags & StateHint) && wmh->initial_state == WithdrawnState)
         {
             c->border = 0;
@@ -685,7 +772,8 @@ client_isvisible(Client *c, int screen)
     return False;
 }
 
-/** Set selected client transparency
+/** Set the transparency of the selected client.
+ * Argument should be an absolut or relativ floating between 0.0 and 1.0
  * \param screen Screen ID
  * \param arg unused arg
  * \ingroup ui_callback
@@ -693,7 +781,7 @@ client_isvisible(Client *c, int screen)
 void
 uicb_client_settrans(int screen __attribute__ ((unused)), char *arg)
 {
-    double delta = 100.0, current_opacity = 100.0;
+    double delta = 1.0, current_opacity = 1.0;
     unsigned char *data;
     Atom actual;
     int format;
@@ -713,7 +801,7 @@ uicb_client_settrans(int screen __attribute__ ((unused)), char *arg)
     {
         memcpy(&current_opacity_raw, data, sizeof(unsigned int));
         XFree(data);
-        current_opacity = (current_opacity_raw * 100.0) / 0xffffffff;
+        current_opacity = (double) current_opacity_raw / 0xffffffff;
     }
     else
         set_prop = 1;
@@ -722,84 +810,82 @@ uicb_client_settrans(int screen __attribute__ ((unused)), char *arg)
 
     if(delta <= 0.0)
         delta = 0.0;
-    else if(delta > 100.0)
+    else if(delta > 1.0)
     {
-        delta = 100.0;
+        delta = 1.0;
         set_prop = 1;
     }
 
-    if(delta == 100.0 && !set_prop)
+    if(delta == 1.0 && !set_prop)
         window_settrans(sel->win, -1);
     else
         window_settrans(sel->win, delta);
 }
 
+/** Find a visible client on screen. Return next client or previous client if
+ * reverse is true.
+ * \param sel current selected client
+ * \param reverse return previous instead of next if true
+ * \return next or previous client
+ */
 static Client *
-client_find_prev_visible(Client *sel)
+client_find_visible(Client *sel, Bool reverse)
 {
-    Client *prev = NULL;
+    Client *next;
+    Client *(*client_iter)(Client **, Client *) = client_list_next_cycle;
 
     if(!sel) return NULL;
 
-    /* look for previous starting at sel */
-    for(prev = client_list_prev_cycle(&globalconf.clients, sel);
-        prev && (prev->skip || !client_isvisible(prev, sel->screen));
-        prev = client_list_prev_cycle(&globalconf.clients, prev));
+    if(reverse)
+        client_iter = client_list_prev_cycle;
 
-    return prev;
-}
+    /* look for previous or next starting at sel */
 
-static Client *
-client_find_next_visible(Client *sel)
-{
-    Client *next = NULL;
-
-    if(!sel) return NULL;
-
-    for(next = sel->next; next && !client_isvisible(next, sel->screen); next = next->next);
-    if(!next)
-        for(next = globalconf.clients; next && !client_isvisible(next, sel->screen); next = next->next);
+    for(next = client_iter(&globalconf.clients, sel);
+        next && next != sel && (next->skip || !client_isvisible(next, sel->screen));
+        next = client_iter(&globalconf.clients, next));
 
     return next;
 }
 
-/** Swap current with previous client
+/** Swap the currently focused client with the previous visible one.
  * \param screen Screen ID
  * \param arg nothing
  * \ingroup ui_callback
  */
 void
-uicb_client_swapprev(int screen __attribute__ ((unused)),
-                     char *arg __attribute__ ((unused)))
+uicb_client_swapprev(int screen __attribute__ ((unused)), char *arg __attribute__ ((unused)))
 {
     Client *prev;
 
-    if((prev = client_find_prev_visible(globalconf.focus->client)))
+    if((prev = client_find_visible(globalconf.focus->client, True)))
     {
         client_list_swap(&globalconf.clients, prev, globalconf.focus->client);
         globalconf.screens[prev->screen].need_arrange = True;
+        widget_invalidate_cache(prev->screen, WIDGET_CACHE_CLIENTS);
     }
 }
 
-/** Swap current with next client
+/** Swap the currently focused client with the next visible one.
  * \param screen Screen ID
  * \param arg nothing
  * \ingroup ui_callback
  */
 void
-uicb_client_swapnext(int screen __attribute__ ((unused)),
-                     char *arg __attribute__ ((unused)))
+uicb_client_swapnext(int screen __attribute__ ((unused)), char *arg __attribute__ ((unused)))
 {
     Client *next;
 
-    if((next = client_find_next_visible(globalconf.focus->client)))
+    if((next = client_find_visible(globalconf.focus->client, False)))
     {
         client_list_swap(&globalconf.clients, globalconf.focus->client, next);
         globalconf.screens[next->screen].need_arrange = True;
+        widget_invalidate_cache(next->screen, WIDGET_CACHE_CLIENTS);
     }
 }
 
-/** Move and resize client
+/** Move and resize a client. Argument should be in format "x y w h" with
+ * absolute (1, 20, 300, ...) or relative (+10, -200, ...) values.
  * \param screen Screen ID
  * \param arg x y w h
  * \ingroup ui_callback
@@ -812,7 +898,7 @@ uicb_client_moveresize(int screen, char *arg)
     int mx, my, dx, dy, nmx, nmy;
     unsigned int dui;
     Window dummy;
-    Area area;
+    area_t geometry;
     Client *sel = globalconf.focus->client;
     Layout *curlay = layout_get_current(screen);
 
@@ -823,10 +909,10 @@ uicb_client_moveresize(int screen, char *arg)
     if(sscanf(arg, "%s %s %s %s", x, y, w, h) != 4)
         return;
 
-    area.x = (int) compute_new_value_from_arg(x, sel->geometry.x);
-    area.y = (int) compute_new_value_from_arg(y, sel->geometry.y);
-    area.width = (int) compute_new_value_from_arg(w, sel->geometry.width);
-    area.height = (int) compute_new_value_from_arg(h, sel->geometry.height);
+    geometry.x = (int) compute_new_value_from_arg(x, sel->geometry.x);
+    geometry.y = (int) compute_new_value_from_arg(y, sel->geometry.y);
+    geometry.width = (int) compute_new_value_from_arg(w, sel->geometry.width);
+    geometry.height = (int) compute_new_value_from_arg(h, sel->geometry.height);
 
     ox = sel->geometry.x;
     oy = sel->geometry.y;
@@ -835,9 +921,11 @@ uicb_client_moveresize(int screen, char *arg)
 
     Bool xqp = XQueryPointer(globalconf.display,
                              RootWindow(globalconf.display,
-                                        get_phys_screen(screen)),
+                                        sel->phys_screen),
                              &dummy, &dummy, &mx, &my, &dx, &dy, &dui);
-    client_resize(sel, area, globalconf.screens[sel->screen].resize_hints);
+    if(globalconf.screens[sel->screen].resize_hints)
+        geometry = client_geometry_hints(sel, geometry);
+    client_resize(sel, geometry, False);
     if (xqp && ox <= mx && (ox + 2 * sel->border + ow) >= mx &&
         oy <= my && (oy + 2 * sel->border + oh) >= my)
     {
@@ -855,6 +943,10 @@ uicb_client_moveresize(int screen, char *arg)
     }
 }
 
+/** Kill a client via a WM_DELETE_WINDOW request or XKillClient if not
+ * supported.
+ * \param c the client to kill
+ */
 void
 client_kill(Client *c)
 {
@@ -874,7 +966,7 @@ client_kill(Client *c)
         XKillClient(globalconf.display, c->win);
 }
 
-/** Kill selected client
+/** Kill the currently focused client.
  * \param screen Screen ID
  * \param arg unused
  * \ingroup ui_callback
@@ -888,39 +980,44 @@ uicb_client_kill(int screen __attribute__ ((unused)), char *arg __attribute__ ((
         client_kill(sel);
 }
 
+/** Maximize the client to the given geometry.
+ * \param c the client to maximize
+ * \param geometry the geometry to use for maximizing
+ */
 static void
-client_maximize(Client *c, Area geometry)
+client_maximize(Client *c, area_t geometry)
 {
-
     if((c->ismax = !c->ismax))
     {
+        /* disable titlebar */
+        c->titlebar.position = Off;
         c->wasfloating = c->isfloating;
         c->m_geometry = c->geometry;
         if(layout_get_current(c->screen)->arrange != layout_floating)
             client_setfloating(c, True);
         client_focus(c, c->screen, True);
         client_resize(c, geometry, False);
-        widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
     }
     else if(c->wasfloating)
     {
+        c->titlebar.position = c->titlebar.dposition;
         client_setfloating(c, True);
         client_resize(c, c->m_geometry, False);
-        widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
     }
     else if(layout_get_current(c->screen)->arrange == layout_floating)
     {
+        c->titlebar.position = c->titlebar.dposition;
         client_resize(c, c->m_geometry, False);
-        widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
     }
     else
     {
+        c->titlebar.position = c->titlebar.dposition;
         client_setfloating(c, False);
-        widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
     }
+    widget_invalidate_cache(c->screen, WIDGET_CACHE_CLIENTS);
 }
 
-/** Toggle maximize for client
+/** Toggle maximization state for the focused client.
  * \param screen Screen ID
  * \param arg Unused
  * \ingroup ui_callback
@@ -929,7 +1026,7 @@ void
 uicb_client_togglemax(int screen, char *arg __attribute__ ((unused)))
 {
     Client *sel = globalconf.focus->client;
-    Area area = screen_get_area(screen,
+    area_t area = screen_get_area(screen,
                                 globalconf.screens[screen].statusbar,
                                 &globalconf.screens[screen].padding);
 
@@ -941,7 +1038,7 @@ uicb_client_togglemax(int screen, char *arg __attribute__ ((unused)))
     }
 }
 
-/** Toggle vertical maximize for client
+/** Toggle vertical maximization for the focused client.
  * \param screen Screen ID
  * \param arg Unused
  * \ingroup ui_callback
@@ -950,7 +1047,7 @@ void
 uicb_client_toggleverticalmax(int screen, char *arg __attribute__ ((unused)))
 {
     Client *sel = globalconf.focus->client;
-    Area area = screen_get_area(screen,
+    area_t area = screen_get_area(screen,
                                 globalconf.screens[screen].statusbar,
                                 &globalconf.screens[screen].padding);
 
@@ -964,7 +1061,7 @@ uicb_client_toggleverticalmax(int screen, char *arg __attribute__ ((unused)))
 }
 
 
-/** Toggle horizontal maximize for client
+/** Toggle horizontal maximization for the focused client.
  * \param screen Screen ID
  * \param arg Unused
  * \ingroup ui_callback
@@ -973,7 +1070,7 @@ void
 uicb_client_togglehorizontalmax(int screen, char *arg __attribute__ ((unused)))
 {
     Client *sel = globalconf.focus->client;
-    Area area = screen_get_area(screen,
+    area_t area = screen_get_area(screen,
                                 globalconf.screens[screen].statusbar,
                                 &globalconf.screens[screen].padding);
 
@@ -986,7 +1083,7 @@ uicb_client_togglehorizontalmax(int screen, char *arg __attribute__ ((unused)))
     }
 }
 
-/** Zoom client
+/** Move the client to the master area.
  * \param screen Screen ID
  * \param arg Unused
  * \ingroup ui_callback
@@ -1011,7 +1108,7 @@ uicb_client_zoom(int screen, char *arg __attribute__ ((unused)))
     }
 }
 
-/** Send focus to next client in stack
+/** Give focus to the next visible client in the stack.
  * \param screen Screen ID
  * \param arg Unused
  * \ingroup ui_callback
@@ -1019,18 +1116,13 @@ uicb_client_zoom(int screen, char *arg __attribute__ ((unused)))
 void
 uicb_client_focusnext(int screen, char *arg __attribute__ ((unused)))
 {
-    Client *c, *sel = globalconf.focus->client;
+    Client *next;
 
-    if(!sel)
-        return;
-    for(c = sel->next; c && (c->skip || !client_isvisible(c, screen)); c = c->next);
-    if(!c)
-        for(c = globalconf.clients; c && (c->skip || !client_isvisible(c, screen)); c = c->next);
-    if(c)
-        client_focus(c, screen, True);
+    if((next = client_find_visible(globalconf.focus->client, False)))
+        client_focus(next, screen, True);
 }
 
-/** Send focus to previous client in stack
+/** Give focus to the previous visible client in the stack.
  * \param screen Screen ID
  * \param arg Unused
  * \ingroup ui_callback
@@ -1040,31 +1132,29 @@ uicb_client_focusprev(int screen, char *arg __attribute__ ((unused)))
 {
     Client *prev;
 
-    if((prev = client_find_prev_visible(globalconf.focus->client)))
+    if((prev = client_find_visible(globalconf.focus->client, True)))
         client_focus(prev, screen, True);
 }
 
-/** Toggle floating state of a client
+/** Toggle the floating state of the focused client.
  * \param screen Screen ID
  * \param arg unused
  * \ingroup ui_callback
  */
 void
-uicb_client_togglefloating(int screen __attribute__ ((unused)),
-                           char *arg __attribute__ ((unused)))
+uicb_client_togglefloating(int screen __attribute__ ((unused)), char *arg __attribute__ ((unused)))
 {
     if(globalconf.focus->client)
         client_setfloating(globalconf.focus->client, !globalconf.focus->client->isfloating);
 }
 
-/** Toggle scratch client attribute
+/** Toggle the scratch client attribute on the focused client.
  * \param screen screen number
  * \param arg unused argument
  * \ingroup ui_callback
  */
 void
-uicb_client_setscratch(int screen,
-                       char *arg __attribute__ ((unused)))
+uicb_client_setscratch(int screen, char *arg __attribute__ ((unused)))
 {
     if(!globalconf.focus->client)
         return;
@@ -1078,14 +1168,13 @@ uicb_client_setscratch(int screen,
     globalconf.screens[screen].need_arrange = True;
 }
 
-/** Toggle scratch client visibility
+/** Toggle the scratch client's visibility.
  * \param screen screen number
  * \param arg unused argument
  * \ingroup ui_callback
  */
 void
-uicb_client_togglescratch(int screen,
-                          char *arg __attribute__ ((unused)))
+uicb_client_togglescratch(int screen, char *arg __attribute__ ((unused)))
 {
     if(globalconf.scratch.client)
     {
@@ -1096,4 +1185,5 @@ uicb_client_togglescratch(int screen,
         widget_invalidate_cache(globalconf.scratch.client->screen, WIDGET_CACHE_CLIENTS);
     }
 }
+
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
