@@ -22,9 +22,20 @@
 #ifndef AWESOME_COMMON_CONFIGOPTS_H
 #define AWESOME_COMMON_CONFIGOPTS_H
 
+#include <confuse.h>
+
+cfg_t * cfg_new(void);
 char * config_file(void);
 int config_check(const char *);
 
+Alignment cfg_opt_getnalignment(cfg_opt_t *, unsigned int);
+Alignment cfg_getnalignment(cfg_t *, const char *, unsigned int);
+Alignment cfg_getalignment(cfg_t *, const char *);
+
+Position cfg_opt_getnposition(cfg_opt_t *, unsigned int);
+Position cfg_getnposition(cfg_t *, const char *, unsigned int);
+Position cfg_getposition(cfg_t *, const char *);
+
 #endif
 
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
