@@ -74,7 +74,9 @@ focus_get_latest_client_for_tags(Tag **t, int nindex)
     int i = 0;
 
     for(node = globalconf.focus; node; node = node->next)
-        if(node->client && !node->client->skip && node->client != globalconf.scratch.client)
+        if(node->client && ((!node->client->skip
+           && node->client != globalconf.scratch.client)
+           || globalconf.scratch.isvisible))
             for(tags = t; *tags; tags++)
                 if(is_client_tagged(node->client, *tags))
                 {
@@ -97,7 +99,8 @@ focus_get_current_client(int screen)
     return sel;
 }
 
-/** Jump in focus history stack
+/** Jump back in the focus history stack.
+ * Set arg to 0 for previous, -1 for previous of previous, etc.
  * \param screen Screen ID
  * \param arg Integer argument
  * \ingroup ui_callback
@@ -124,6 +127,11 @@ uicb_focus_history(int screen, char *arg)
     }
 }
 
+/** Focus one of the visible clients by its name.
+ * \param screen screen id
+ * \param arg client's name
+ * \ingroup ui_callback
+ */
 void
 uicb_focus_client_byname(int screen, char *arg)
 {
