@@ -1,7 +1,7 @@
 /*
  * layout.h - layout management header
  *
- * Copyright © 2007 Julien Danjou <julien@danjou.info>
+ * Copyright © 2007-2008 Julien Danjou <julien@danjou.info>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,10 +35,10 @@ struct Layout
 {
     char *image;
     LayoutArrange *arrange;
-    Layout *next;
+    Layout *prev, *next;
 };
 
-DO_SLIST(Layout, layout, p_delete);
+DO_SLIST(Layout, layout, p_delete)
 
 int layout_refresh(void);
 Layout * layout_get_current(int);
