@@ -32,6 +32,6 @@ layout_floating(int screen)
 
     for(c = globalconf.clients; c; c = c->next)
         if(client_isvisible(c, screen) && !c->ismax)
-            client_resize(c, c->f_geometry, True);
+            client_resize(c, c->f_geometry, False);
 }
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
