@@ -31,7 +31,7 @@ void
 layout_max(int screen)
 {
     Client *c;
-    Area area = screen_get_area(screen,
+    area_t area = screen_get_area(screen,
                                 globalconf.screens[screen].statusbar,
                                 &globalconf.screens[screen].padding);
 
@@ -40,7 +40,7 @@ layout_max(int screen)
         {
             area.width -= 2 * c->border;
             area.height -= 2 * c->border;
-            client_resize(c, area, globalconf.screens[screen].resize_hints);
+            client_resize(c, area, False);
             area.width += 2 * c->border;
             area.height += 2 * c->border;
         }
