@@ -1,7 +1,7 @@
 /*
  * rules.c - rules management
  *
- * Copyright © 2007 Julien Danjou <julien@danjou.info>
+ * Copyright © 2007-2008 Julien Danjou <julien@danjou.info>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,10 @@
  *
  */
 
+#include <X11/Xutil.h>
+
 #include "rules.h"
-#include "xutil.h"
+#include "common/xutil.h"
 
 extern AwesomeConf globalconf;
 
@@ -77,7 +79,7 @@ client_match_rule(Client *c, Rule *r)
 
     if(r->xprop
        && r->xpropval_r
-       && xgettextprop(c->win,
+       && xgettextprop(globalconf.display, c->win,
                        XInternAtom(globalconf.display, r->xprop, False),
                        buf, ssizeof(buf)))
         ret = !regexec(r->xpropval_r, buf, 1, &tmp, 0);
@@ -115,7 +117,7 @@ rules_get_fuzzy_from_str(const char *str)
     else if(!a_strcmp(str, "false") || !a_strcmp(str, "no"))
         return No;
 
-    return Auto;
+    return Maybe;
 }
 
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
