@@ -24,11 +24,9 @@
 
 #include "structs.h"
 
-Area screen_get_area(int, Statusbar *, Padding *);
-Area get_display_area(int, Statusbar *, Padding *);
-int screen_get_bycoord(int, int, int);
-void screen_build_screens(void);
-int get_phys_screen(int);
+area_t screen_get_area(int, Statusbar *, Padding *);
+area_t get_display_area(int, Statusbar *, Padding *);
+int screen_virttophys(int);
 void move_client_to_screen(Client *, int, Bool);
 
 Uicb uicb_screen_focus;
