@@ -1,7 +1,7 @@
 /*
  * statusbar.h - statusbar functions header
  *
- * Copyright © 2007 Julien Danjou <julien@danjou.info>
+ * Copyright © 2007-2008 Julien Danjou <julien@danjou.info>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,11 +28,11 @@ void statusbar_refresh(void);
 void statusbar_preinit(Statusbar *);
 void statusbar_init(Statusbar *);
 void statusbar_display(Statusbar *);
-Position statusbar_get_position_from_str(const char *);
+Statusbar * statusbar_getbyname(int, const char *);
 
 Uicb uicb_statusbar_toggle;
 
-DO_SLIST(Statusbar, statusbar, p_delete);
+DO_SLIST(Statusbar, statusbar, p_delete)
 
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
