@@ -1,7 +1,7 @@
 /*
  * uicb.h - user interface callbacks management header
  *
- * Copyright © 2007 Julien Danjou <julien@danjou.info>
+ * Copyright © 2007-2008 Julien Danjou <julien@danjou.info>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,5 +26,9 @@ typedef void (Uicb)(int, char *);
 
 int parse_control(char *);
 
+Uicb uicb_restart;
+Uicb uicb_exec;
+Uicb uicb_spawn;
+
 #endif
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
