@@ -88,20 +88,18 @@ widget_calculate_offset(int barwidth, int widgetwidth, int offset, int alignment
 }
 
 /** Find a widget on a screen by its name
+ * \param statusbar the statusbar to look into
  * \param name the widget name
- * \param screen the screen to look into
  * \return a widget
  */
 static Widget *
-widget_find(char *name, int screen)
+widget_getbyname(Statusbar *sb, char *name)
 {
     Widget *widget;
-    Statusbar *sb;
 
-    for(sb = globalconf.screens[screen].statusbar; sb; sb = sb->next)
-        for(widget = sb->widgets; widget; widget = widget->next)
-            if(a_strcmp(name, widget->name) == 0)
-                return widget;
+    for(widget = sb->widgets; widget; widget = widget->next)
+        if(!a_strcmp(name, widget->name))
+            return widget;
 
     return NULL;
 }
@@ -128,11 +126,14 @@ widget_common_button_press(Widget *widget, XButtonPressedEvent *ev)
  * cannot be told anything
  * \param widget the widget
  * \param command unused argument
+ * \return widget_tell_status_t enum (see structs.h)
  */
-static void
-widget_common_tell(Widget *widget, char *command __attribute__ ((unused)))
+static widget_tell_status_t
+widget_common_tell(Widget *widget, char *property __attribute__ ((unused)),
+                   char *command __attribute__ ((unused)))
 {
     warn("%s widget does not accept commands.\n", widget->name);
+    return WIDGET_ERROR_CUSTOM;
 }
 
 /** Common function for creating a widget
@@ -173,7 +174,7 @@ widget_invalidate_cache(int screen, int flags)
                 widget->cache.needs_update = True;
 }
 
-/** Send command to widget
+/** Send commands to widgets.
  * \param screen Screen ID
  * \param arg Widget command. Syntax depends on specific widget.
  * \ingroup ui_callback
@@ -181,46 +182,80 @@ widget_invalidate_cache(int screen, int flags)
 void
 uicb_widget_tell(int screen, char *arg)
 {
+    Statusbar *statusbar;
     Widget *widget;
-    char *p, *command;
+    char *p, *property = NULL, *command;
     ssize_t len;
+    widget_tell_status_t status;
 
-    if (!arg)
-    {
-        warn("Must specify a widget.\n");
-        return;
-    }
+    if(!(len = a_strlen(arg)))
+        return warn("must specify a statusbar and a widget.\n");
 
-    len = a_strlen(arg);
-    p = strtok(arg, " ");
-    if(!p)
-    {
-        warn("Ignoring malformed widget command.\n");
-        return;
-    }
+    if(!(p = strtok(arg, " ")))
+        return warn("ignoring malformed widget command (missing statusbar name).\n");
 
-    widget = widget_find(p, screen);
-    if(!widget)
-    {
-        warn("No such widget: %s\n", p);
-        return;
-    }
+    if(!(statusbar = statusbar_getbyname(screen, p)))
+        return warn("no such statusbar: %s\n", p);
 
-    if(p + a_strlen(p) < arg + len)
+    if(!(p = strtok(NULL, " ")))
+        return warn("ignoring malformed widget command (missing widget name).\n");
+
+    if(!(widget = widget_getbyname(statusbar, p)))
+        return warn("no such widget: %s in statusbar %s.\n", p, statusbar->name);
+
+    if(!(p = strtok(NULL, " ")))
+        return warn("ignoring malformed widget command (missing property name).\n");
+
+    property = p;
+    p += a_strlen(property) + 1; /* could be out of 'arg' now */
+
+    /* arg + len points to the finishing \0.
+     * p to the char right of the first space (strtok delimiter)
+     *
+     * \0 is on the right(>) of p pointer => some text (command) */
+    if(arg + len > p)
     {
-        p = p + a_strlen(p) + 1;
         len = a_strlen(p);
         command = p_new(char, len + 1);
         a_strncpy(command, len + 1, p, len);
-        widget->tell(widget, command);
+        status = widget->tell(widget, property, command);
         p_delete(&command);
     }
     else
-        widget->tell(widget, NULL);
+        status = widget->tell(widget, property, NULL);
 
-    widget->cache.needs_update = True;
-
-    return;
+    switch(status)
+    {
+      case WIDGET_ERROR:
+        warn("error changing property %s of widget %s\n",
+             property, widget->name);
+        break;
+      case WIDGET_ERROR_NOVALUE:
+          warn("error changing property %s of widget %s, no value given\n",
+                property, widget->name);
+        break;
+      case WIDGET_ERROR_FORMAT_BOOL:
+        warn("error changing property %s of widget %s, must is boolean (0 or 1)\n",
+             property, widget->name);
+        break;
+      case WIDGET_ERROR_FORMAT_FONT:
+        warn("error changing property %s of widget %s, must be a valid font\n",
+             property, widget->name);
+        break;
+      case WIDGET_ERROR_FORMAT_COLOR:
+        warn("error changing property %s of widget %s, must be a valid color\n",
+             property, widget->name);
+        break;
+      case WIDGET_ERROR_FORMAT_SECTION:
+        warn("error changing property %s of widget %s, section/title not found\n",
+             property, widget->name);
+        break;
+      case WIDGET_NOERROR:
+          widget->cache.needs_update = True;
+          break;
+      case WIDGET_ERROR_CUSTOM:
+        break;
+    }
 }
 
 // vim: filetype=c:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=80
