@@ -1,7 +1,7 @@
 /*
  * widget.h - widget managing header
  *
- * Copyright © 2007 Julien Danjou <julien@danjou.info>
+ * Copyright © 2007-2008 Julien Danjou <julien@danjou.info>
  * Copyright © 2007 Aldo Cortesi <aldo@nullcube.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,6 +42,7 @@ void widget_common_new(Widget*, Statusbar *, cfg_t *);
 WidgetConstructor layoutinfo_new;
 WidgetConstructor taglist_new;
 WidgetConstructor textbox_new;
+WidgetConstructor emptybox_new;
 WidgetConstructor iconbox_new;
 WidgetConstructor focusicon_new;
 WidgetConstructor progressbar_new;
@@ -50,7 +51,7 @@ WidgetConstructor tasklist_new;
 
 Uicb uicb_widget_tell;
 
-DO_SLIST(Widget, widget, p_delete);
+DO_SLIST(Widget, widget, p_delete)
 
 #endif
 
