@@ -21,6 +21,7 @@
 
 #include "widget.h"
 #include "common/util.h"
+#include "common/configopts.h"
 
 extern AwesomeConf globalconf;
 
@@ -35,7 +36,7 @@ iconbox_draw(Widget *widget, DrawCtx *ctx, int offset,
              int used __attribute__ ((unused)))
 {
     Data *d = widget->data;
-    Area area = draw_get_image_size(d->image);
+    area_t area = draw_get_image_size(d->image);
 
     /* image not valid */
     if(area.width < 0 || area.height < 0)
@@ -63,14 +64,32 @@ iconbox_draw(Widget *widget, DrawCtx *ctx, int offset,
     return widget->area.width;
 }
 
-static void
-iconbox_tell(Widget *widget, char *command)
+static widget_tell_status_t
+iconbox_tell(Widget *widget, char *property, char *command)
 {
+    Bool b;
     Data *d = widget->data;
 
-    if(d->image)
-        p_delete(&d->image);
-    d->image = a_strdup(command);
+    if(command == NULL)
+        return WIDGET_ERROR_NOVALUE;
+
+    if(!a_strcmp(property, "image"))
+    {
+        if(d->image)
+            p_delete(&d->image);
+        d->image = a_strdup(command);
+    }
+    else if(!a_strcmp(property, "resize"))
+    {
+        if((b = cfg_parse_boolean(command)) != -1)
+            d->resize = b;
+        else
+            return WIDGET_ERROR_FORMAT_BOOL;
+    }
+    else
+       return WIDGET_ERROR;
+
+    return WIDGET_NOERROR;
 }
 
 Widget *
@@ -81,7 +100,7 @@ iconbox_new(Statusbar *statusbar, cfg_t *config)
 
     w = p_new(Widget, 1);
     widget_common_new(w, statusbar, config);
-    w->alignment = draw_get_align(cfg_getstr(config, "align"));
+    w->alignment = cfg_getalignment(config, "align");
     w->draw = iconbox_draw;
     w->tell = iconbox_tell;
     w->data = d = p_new(Data, 1);
