@@ -24,6 +24,7 @@
 #include "widget.h"
 #include "tag.h"
 #include "common/util.h"
+#include "common/configopts.h"
 
 extern AwesomeConf globalconf;
 
@@ -34,7 +35,7 @@ layoutinfo_draw(Widget *widget,
                 int used __attribute__ ((unused)))
 {
     Tag **curtags = tags_get_current(widget->statusbar->screen);
-    Area area = draw_get_image_size(curtags[0]->layout->image);
+    area_t area = draw_get_image_size(curtags[0]->layout->image);
 
     if(!widget->user_supplied_x)
         widget->area.x = widget_calculate_offset(widget->statusbar->width,
@@ -64,7 +65,7 @@ layoutinfo_new(Statusbar *statusbar, cfg_t* config)
     w = p_new(Widget, 1);
     widget_common_new(w, statusbar, config);
     w->draw = layoutinfo_draw;
-    w->alignment = draw_get_align(cfg_getstr(config, "align"));
+    w->alignment = cfg_getalignment(config, "align");
 
     /* Set cache property */
     w->cache.flags = WIDGET_CACHE_LAYOUTS;
