@@ -28,6 +28,7 @@
 #include "rules.h"
 #include "tag.h"
 #include "common/util.h"
+#include "common/configopts.h"
 
 extern AwesomeConf globalconf;
 
@@ -43,10 +44,12 @@ typedef struct
     ShowClient show;
     Bool show_icons;
     Alignment align;
-    XColor fg_sel;
-    XColor bg_sel;
-    XColor fg;
-    XColor bg;
+    struct
+    {
+        style_t normal;
+        style_t focus;
+        style_t urgent;
+    } styles;
 } Data;
 
 static inline Bool
@@ -58,19 +61,12 @@ tasklist_isvisible(Client *c, int screen, ShowClient show)
     switch(show)
     {
       case ShowAll:
-        if(c->screen == screen)
-            return True;
-        break;
+        return (c->screen == screen);
       case ShowTags:
-        if(client_isvisible(c, screen))
-            return True;
-        break;
+        return client_isvisible(c, screen);
       case ShowFocus:
-        if(c == globalconf.focus->client)
-            return True;
-        break;
+        return (c == focus_get_current_client(screen));
     }
-
     return False;
 }
 
@@ -79,9 +75,9 @@ tasklist_draw(Widget *widget, DrawCtx *ctx, int offset, int used)
 {
     Client *c;
     Data *d = widget->data;
-    Client *sel = focus_get_current_client(widget->statusbar->screen);
     Rule *r;
-    Area area;
+    area_t area;
+    style_t style;
     int n = 0, i = 0, box_width = 0, icon_width = 0, box_width_rest = 0;
     NetWMIcon *icon;
 
@@ -113,6 +109,13 @@ tasklist_draw(Widget *widget, DrawCtx *ctx, int offset, int used)
         {
             icon_width = 0;
 
+            if(c->isurgent)
+                style = d->styles.urgent;
+            else if(globalconf.focus->client == c)
+                style = d->styles.focus;
+            else
+                style = d->styles.normal;
+
             if(d->show_icons)
             {
                 /* draw a background for icons */
@@ -120,10 +123,8 @@ tasklist_draw(Widget *widget, DrawCtx *ctx, int offset, int used)
                 area.y = widget->area.y;
                 area.height = widget->statusbar->height;
                 area.width = box_width;
-                if(sel == c)
-                    draw_rectangle(ctx, area, True, d->bg_sel);
-                else
-                    draw_rectangle(ctx, area, True, d->bg);
+
+                draw_rectangle(ctx, area, 1.0, True, style.bg);
 
                 if((r = rule_matching_client(c)) && r->icon)
                 {
@@ -162,28 +163,23 @@ tasklist_draw(Widget *widget, DrawCtx *ctx, int offset, int used)
             if(i == n - 1)
                 area.width += box_width_rest;
 
-            if(sel == c)
-                draw_text(ctx, area, d->align,
-                          widget->font->height / 2, widget->font, c->name,
-                          d->fg_sel, d->bg_sel);
-            else
-                draw_text(ctx, area, d->align,
-                          widget->font->height / 2, widget->font, c->name,
-                          d->fg, d->bg);
+            draw_text(ctx, area, d->align,
+                      style.font->height / 2, c->name,
+                      style);
 
             if(c == globalconf.scratch.client)
             {
                 area.x = widget->area.x + icon_width + box_width * i;
                 area.y = widget->area.y;
-                area.width = (widget->font->height + 2) / 3;
-                area.height = (widget->font->height + 2) / 3;
-                draw_rectangle(ctx, area, c->isfloating, d->fg);
+                area.width = (style.font->height + 2) / 3;
+                area.height = (style.font->height + 2) / 3;
+                draw_rectangle(ctx, area, 1.0, c->isfloating, style.fg);
             }
             else if(c->isfloating || c->ismax)
                 draw_circle(ctx, widget->area.x + icon_width + box_width * i,
                             widget->area.y,
-                            (widget->font->height + 2) / 4,
-                            c->ismax, d->fg);
+                            (style.font->height + 2) / 4,
+                            c->ismax, style.fg);
             i++;
         }
 
@@ -267,7 +263,7 @@ tasklist_new(Statusbar *statusbar, cfg_t *config)
     Widget *w;
     Data *d;
     char *buf;
-    int phys_screen = get_phys_screen(statusbar->screen);
+    cfg_t *cfg_styles;
 
     w = p_new(Widget, 1);
     widget_common_new(w, statusbar, config);
@@ -276,27 +272,24 @@ tasklist_new(Statusbar *statusbar, cfg_t *config)
     w->alignment = AlignFlex;
     w->data = d = p_new(Data, 1);
 
-    if((buf = cfg_getstr(config, "fg")))
-        draw_color_new(globalconf.display, phys_screen, buf, &d->fg);
-    else
-        d->fg = globalconf.screens[statusbar->screen].colors_normal[ColFG];
+    cfg_styles = cfg_getsec(config, "styles");
 
-    if((buf = cfg_getstr(config, "bg")))
-        draw_color_new(globalconf.display, phys_screen, buf, &d->bg);
-    else
-        d->bg = globalconf.screens[statusbar->screen].colors_normal[ColBG];
+    draw_style_init(globalconf.display, statusbar->phys_screen,
+                    cfg_getsec(cfg_styles, "normal"),
+                    &d->styles.normal,
+                    &globalconf.screens[statusbar->screen].styles.normal);
 
-    if((buf = cfg_getstr(config, "focus_bg")))
-        draw_color_new(globalconf.display, phys_screen, buf, &d->bg_sel);
-    else
-        d->bg_sel = globalconf.screens[statusbar->screen].colors_selected[ColBG];
+    draw_style_init(globalconf.display, statusbar->phys_screen,
+                    cfg_getsec(cfg_styles, "focus"),
+                    &d->styles.focus,
+                    &globalconf.screens[statusbar->screen].styles.focus);
 
-    if((buf = cfg_getstr(config, "focus_fg")))
-        draw_color_new(globalconf.display, phys_screen, buf, &d->fg_sel);
-    else
-        d->fg_sel = globalconf.screens[statusbar->screen].colors_selected[ColFG];
+    draw_style_init(globalconf.display, statusbar->phys_screen,
+                    cfg_getsec(cfg_styles, "urgent"),
+                    &d->styles.urgent,
+                    &globalconf.screens[statusbar->screen].styles.urgent);
 
-    d->align = draw_get_align(cfg_getstr(config, "text_align"));
+    d->align = cfg_getalignment(config, "text_align");
     d->show_icons = cfg_getbool(config, "show_icons");
 
     buf = cfg_getstr(config, "show");
@@ -307,12 +300,6 @@ tasklist_new(Statusbar *statusbar, cfg_t *config)
     else
         d->show = ShowFocus;
 
-    if((buf = cfg_getstr(config, "font")))
-        w->font = XftFontOpenName(globalconf.display, get_phys_screen(statusbar->screen), buf);
-
-    if(!w->font)
-        w->font = globalconf.screens[statusbar->screen].font;
-
     /* Set cache property */
     w->cache.flags = WIDGET_CACHE_CLIENTS;
 
