@@ -74,7 +74,7 @@ window_getstate(Window w)
  * \return the XSendEvent() status
  */
 Status
-window_configure(Window win, Area geometry, int border)
+window_configure(Window win, area_t geometry, int border)
 {
     XConfigureEvent ce;
 
@@ -93,11 +93,11 @@ window_configure(Window win, Area geometry, int border)
 }
 
 /** Grab or ungrab buttons on a window
- * \param screen The screen
  * \param win The window
+ * \param phys_screen Physical screen number
  */
 void
-window_grabbuttons(int phys_screen, Window win)
+window_grabbuttons(Window win, int phys_screen)
 {
     Button *b;
 
@@ -157,32 +157,36 @@ void
 window_root_grabkeys(int phys_screen)
 {
     Key *k;
+    KeyCode kc;
 
     XUngrabKey(globalconf.display, AnyKey, AnyModifier, RootWindow(globalconf.display, phys_screen));
 
     for(k = globalconf.keys; k; k = k->next)
-	if(k->keycode)
+	if((kc = k->keycode) || (k->keysym && (kc = XKeysymToKeycode(globalconf.display, k->keysym))))
         {
-             XGrabKey(globalconf.display, k->keycode, k->mod,
-                      RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
-             XGrabKey(globalconf.display, k->keycode, k->mod | LockMask,
-                      RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
-             XGrabKey(globalconf.display, k->keycode, k->mod | globalconf.numlockmask,
-                      RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
-             XGrabKey(globalconf.display, k->keycode, k->mod | globalconf.numlockmask | LockMask,
-                      RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
+            XGrabKey(globalconf.display, kc, k->mod,
+                     RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
+            XGrabKey(globalconf.display, kc, k->mod | LockMask,
+                     RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
+            XGrabKey(globalconf.display, kc, k->mod | globalconf.numlockmask,
+                     RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
+            XGrabKey(globalconf.display, kc, k->mod | globalconf.numlockmask | LockMask,
+                     RootWindow(globalconf.display, phys_screen), True, GrabModeAsync, GrabModeAsync);
         }
 }
 
 void
-window_setshape(int screen, Window win)
+window_setshape(Window win, int phys_screen)
 {
-    int bounding_shaped;
-    int i, b;  unsigned int u;  /* dummies */
+    int bounding_shaped, i, b;
+    unsigned int u;  /* dummies */
+
     /* Logic to decide if we have a shaped window cribbed from fvwm-2.5.10. */
     if(XShapeQueryExtents(globalconf.display, win, &bounding_shaped, &i, &i,
                           &u, &u, &b, &i, &i, &u, &u) && bounding_shaped)
-        XShapeCombineShape(globalconf.display, RootWindow(globalconf.display, screen), ShapeBounding, 0, 0, win, ShapeBounding, ShapeSet);
+        XShapeCombineShape(globalconf.display,
+                           RootWindow(globalconf.display, phys_screen),
+                           ShapeBounding, 0, 0, win, ShapeBounding, ShapeSet);
 }
 
 int
@@ -191,9 +195,9 @@ window_settrans(Window win, double opacity)
     int status;
     unsigned int real_opacity = 0xffffffff;
 
-    if(opacity >= 0 && opacity <= 100)
+    if(opacity >= 0 && opacity <= 1)
     {
-        real_opacity = ((opacity / 100.0) * 0xffffffff);
+        real_opacity = opacity * 0xffffffff;
         status = XChangeProperty(globalconf.display, win,
                                  XInternAtom(globalconf.display, "_NET_WM_WINDOW_OPACITY", False),
                                  XA_CARDINAL, 32, PropModeReplace, (unsigned char *) &real_opacity, 1L);
