@@ -26,11 +26,11 @@
 
 int window_setstate(Window, long);
 long window_getstate(Window);
-Status window_configure(Window, Area, int);
-void window_grabbuttons(int, Window);
+Status window_configure(Window, area_t, int);
+void window_grabbuttons(Window, int);
 void window_root_grabbuttons(int);
 void window_root_grabkeys(int);
-void window_setshape(int, Window);
+void window_setshape(Window, int);
 int window_settrans(Window, double);
 
 #endif
